@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2017 IBM Corporation and others.
+ * Copyright (c) 2013, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,7 +14,6 @@
 package org.eclipse.osgi.tests.hooks.framework.activator.a;
 
 import java.util.List;
-import org.eclipse.osgi.internal.hookregistry.ActivatorHookFactory;
 import org.eclipse.osgi.internal.hookregistry.HookConfigurator;
 import org.eclipse.osgi.internal.hookregistry.HookRegistry;
 import org.osgi.framework.BundleActivator;
@@ -25,25 +24,19 @@ public class TestHookConfigurator3 implements HookConfigurator {
 
 	@Override
 	public void addHooks(HookRegistry hookRegistry) {
-		hookRegistry.addActivatorHookFactory(new ActivatorHookFactory() {
+		hookRegistry.addActivatorHookFactory(() -> new BundleActivator() {
+			@Override
+			public void start(BundleContext context) throws Exception {
+				if (events != null) {
+					events.add("HOOK3 STARTED");
+				}
+			}
 
 			@Override
-			public BundleActivator createActivator() {
-				return new BundleActivator() {
-					@Override
-					public void start(BundleContext context) throws Exception {
-						if (events != null) {
-							events.add("HOOK3 STARTED");
-						}
-					}
-
-					@Override
-					public void stop(BundleContext context) throws Exception {
-						if (events != null) {
-							events.add("HOOK3 STOPPED");
-						}
-					}
-				};
+			public void stop(BundleContext context) throws Exception {
+				if (events != null) {
+					events.add("HOOK3 STOPPED");
+				}
 			}
 		});
 
