@@ -1,26 +1,25 @@
 /*******************************************************************************
-n
-n This program
- * and the accompanying materials are made available under the terms of the
- * Eclipse Public License 2.0 which accompanies this distribution, and is
- * available at
+ * Copyright (c) 2020 Cognos Incorporated, IBM Corporation and others
+ *
+ * This program and the accompanying materials are made
+ * available under the terms of the Eclipse Public License 2.0 which
+ * accompanies this distribution, and is available at
  * https://www.eclipse.org/legal/epl-2.0/
  *
  * SPDX-License-Identifier: EPL-2.0
- *******************************************************************************/
+ ******************************************************************************/
 package org.eclipse.equinox.log.test;
 
-import java.util.ArrayList;
-import java.util.List;
+import java.util.LinkedList;
 import org.eclipse.equinox.log.ExtendedLogEntry;
 import org.eclipse.osgi.tests.OSGiTestsActivator;
 import org.junit.Assert;
 import org.osgi.service.log.LogEntry;
 import org.osgi.service.log.LogListener;
 
-class TestListener implements LogListener {
+public class TestListener implements LogListener {
 	private final String testBundleLoc;
-	private List<LogEntry> logs = new ArrayList<>();
+	private LinkedList<LogEntry> logs = new LinkedList<>();
 
 	public TestListener() {
 		this(null);
@@ -45,11 +44,11 @@ class TestListener implements LogListener {
 	public synchronized ExtendedLogEntry getEntryX(long timeToWait) throws InterruptedException {
 		LogEntry logEntry;
 		long startTime = System.currentTimeMillis();
-		if (logs.size() == 0 && timeToWait > 0) {
+		if (logs.isEmpty() && timeToWait > 0) {
 			this.wait(timeToWait);
 			timeToWait = timeToWait - (System.currentTimeMillis() - startTime);
 		}
-		logEntry = logs.size() == 0 ? null : logs.remove(0);
+		logEntry = logs.isEmpty() ? null : logs.removeFirst();
 		if (logEntry == null) {
 			Assert.fail("No log entry logged.");
 		}
