@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2013, 2017 IBM Corporation and others.
+ * Copyright (c) 2013, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.osgi.tests.hooks.framework;
 
+import static org.eclipse.osgi.tests.bundles.AbstractBundleTests.stopQuietly;
+
 import java.io.File;
 import java.io.IOException;
 import java.net.URL;
@@ -34,7 +36,7 @@ public class ContextFinderTests extends AbstractFrameworkHookTests {
 	protected void setUp() throws Exception {
 		super.setUp();
 		File file = OSGiTestsActivator.getContext().getDataFile(getName());
-		configuration = new HashMap<String, String>();
+		configuration = new HashMap<>();
 		configuration.put(Constants.FRAMEWORK_STORAGE, file.getAbsolutePath());
 		framework = createFramework(configuration);
 		initAndStart(framework);
