@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2018 IBM Corporation and others.
+ * Copyright (c) 2004, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -74,12 +74,7 @@ public class BundleLoader extends ModuleLoader {
 	public final static String DEFAULT_PACKAGE = "."; //$NON-NLS-1$
 	public final static String JAVA_PACKAGE = "java."; //$NON-NLS-1$
 
-	public final static ClassContext CLASS_CONTEXT = AccessController.doPrivileged(new PrivilegedAction<ClassContext>() {
-		@Override
-		public ClassContext run() {
-			return new ClassContext();
-		}
-	});
+	public final static ClassContext CLASS_CONTEXT = AccessController.doPrivileged((PrivilegedAction<ClassContext>) ClassContext::new);
 	public final static ClassLoader FW_CLASSLOADER = getClassLoader(EquinoxContainer.class);
 
 	private static final int PRE_CLASS = 1;
@@ -174,7 +169,7 @@ public class BundleLoader extends ModuleLoader {
 		// init the provided packages set
 		exportSources = new BundleLoaderSources(this);
 		List<ModuleCapability> exports = wiring.getModuleCapabilities(PackageNamespace.PACKAGE_NAMESPACE);
-		exports = exports == null ? new ArrayList<ModuleCapability>(0) : exports;
+		exports = exports == null ? Collections.emptyList() : exports;
 		exportedPackages = Collections.synchronizedCollection(exports.size() > 10 ? new HashSet<String>(exports.size()) : new ArrayList<String>(exports.size()));
 		initializeExports(exports, exportSources, exportedPackages);
 
@@ -183,13 +178,16 @@ public class BundleLoader extends ModuleLoader {
 
 		// initialize the required bundle wires
 		List<ModuleWire> currentRequireBundleWires = wiring.getRequiredModuleWires(BundleNamespace.BUNDLE_NAMESPACE);
-		requiredBundleWires = currentRequireBundleWires == null || currentRequireBundleWires.isEmpty() ? Collections.<ModuleWire> emptyList() : Collections.unmodifiableList(currentRequireBundleWires);
+		requiredBundleWires = currentRequireBundleWires == null || currentRequireBundleWires.isEmpty() ? Collections.emptyList() : Collections.unmodifiableList(currentRequireBundleWires);
 
 		//Initialize the policy handler
 		List<ModuleCapability> moduleDatas = wiring.getRevision().getModuleCapabilities(EquinoxModuleDataNamespace.MODULE_DATA_NAMESPACE);
 		@SuppressWarnings("unchecked")
 		List<String> buddyList = (List<String>) (moduleDatas.isEmpty() ? null : moduleDatas.get(0).getAttributes().get(EquinoxModuleDataNamespace.CAPABILITY_BUDDY_POLICY));
-		policy = buddyList != null ? new PolicyHandler(this, buddyList, container.getPackageAdmin()) : null;
+		policy = buddyList != null
+				? new PolicyHandler(this, buddyList, container.getStorage().getModuleContainer().getFrameworkWiring(),
+						container.getBootLoader())
+				: null;
 		if (policy != null) {
 			Module systemModule = container.getStorage().getModuleContainer().getModule(0);
 			Bundle systemBundle = systemModule.getBundle();
@@ -213,7 +211,7 @@ public class BundleLoader extends ModuleLoader {
 					if (!exportNames.contains(name)) {
 						// must force filtered and reexport sources to be created early
 						// to prevent lazy normal package source creation.
-						// We only do this for the first export of a package name. 
+						// We only do this for the first export of a package name.
 						sources.createPackageSource(export, true);
 					}
 				}
@@ -263,12 +261,8 @@ public class BundleLoader extends ModuleLoader {
 			result = createClassLoaderPrivledged(parent, generation.getBundleInfo().getStorage().getConfiguration(), this, generation, hooks);
 		} else {
 			final ClassLoader cl = parent;
-			result = AccessController.doPrivileged(new PrivilegedAction<ModuleClassLoader>() {
-				@Override
-				public ModuleClassLoader run() {
-					return createClassLoaderPrivledged(cl, generation.getBundleInfo().getStorage().getConfiguration(), BundleLoader.this, generation, hooks);
-				}
-			});
+			result = AccessController.doPrivileged((PrivilegedAction<ModuleClassLoader>)
+					() -> createClassLoaderPrivledged(cl, generation.getBundleInfo().getStorage().getConfiguration(), BundleLoader.this, generation, hooks));
 		}
 
 		// Synchronize on classLoaderCreatedMonitor in order to ensure hooks are called before returning.
@@ -282,15 +276,11 @@ public class BundleLoader extends ModuleLoader {
 				// only send to hooks if this thread wins in creating the class loader.
 				final ModuleClassLoader cl = result;
 				// protect with doPriv to avoid bubbling up permission checks that hooks may require
-				AccessController.doPrivileged(new PrivilegedAction<Object>() {
-					@Override
-					public Object run() {
-						for (ClassLoaderHook hook : hooks) {
-							hook.classLoaderCreated(cl);
-						}
-						return null;
+				AccessController.doPrivileged((PrivilegedAction<Object>) () -> {
+					for (ClassLoaderHook hook : hooks) {
+						hook.classLoaderCreated(cl);
 					}
-
+					return null;
 				});
 				// finally set the class loader for use after calling hooks
 				classloader = classLoaderCreated;
@@ -370,9 +360,9 @@ public class BundleLoader extends ModuleLoader {
 	}
 
 	/**
-	 * This method gets a resource from the bundle.  The resource is searched 
-	 * for in the same manner as it would if it was being loaded from a bundle 
-	 * (i.e. all hosts, fragments, import, required bundles and 
+	 * This method gets a resource from the bundle.  The resource is searched
+	 * for in the same manner as it would if it was being loaded from a bundle
+	 * (i.e. all hosts, fragments, import, required bundles and
 	 * local resources are searched).
 	 *
 	 * @param name the name of the desired resource.
@@ -386,7 +376,7 @@ public class BundleLoader extends ModuleLoader {
 	 * Finds a class local to this bundle.  Only the classloader for this bundle is searched.
 	 * @param name The name of the class to find.
 	 * @return The loaded Class or null if the class is not found.
-	 * @throws ClassNotFoundException 
+	 * @throws ClassNotFoundException
 	 */
 	public Class<?> findLocalClass(String name) throws ClassNotFoundException {
 		long start = 0;
@@ -414,24 +404,20 @@ public class BundleLoader extends ModuleLoader {
 	 * Finds the class for a bundle.  This method is used for delegation by the bundle's classloader.
 	 */
 	public Class<?> findClass(String name) throws ClassNotFoundException {
-		return findClass(name, true);
-	}
 
-	Class<?> findClass(String name, boolean checkParent) throws ClassNotFoundException {
-		if (checkParent && parent != null && name.startsWith(JAVA_PACKAGE))
+		if (parent != null && name.startsWith(JAVA_PACKAGE)) {
 			// 1) if startsWith "java." delegate to parent and terminate search
 			// we want to throw ClassNotFoundExceptions if a java.* class cannot be loaded from the parent.
 			return parent.loadClass(name);
-		return findClassInternal(name, checkParent);
-	}
+		}
 
-	private Class<?> findClassInternal(String name, boolean checkParent) throws ClassNotFoundException {
 		if (debug.DEBUG_LOADER)
-			Debug.println("BundleLoader[" + this + "].findClassInternal(" + name + ")"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			Debug.println("BundleLoader[" + this + "].findClass(" + name + ")"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+
 		String pkgName = getPackageName(name);
 		boolean bootDelegation = false;
 		// follow the OSGi delegation model
-		if (checkParent && parent != null && container.isBootDelegationPackage(pkgName)) {
+		if (parent != null && container.isBootDelegationPackage(pkgName)) {
 			// 2) if part of the bootdelegation list then delegate to parent and continue of failure
 			try {
 				return parent.loadClass(name);
@@ -458,6 +444,11 @@ public class BundleLoader extends ModuleLoader {
 			}
 			// 3) found import source terminate search at the source
 			result = source.loadClass(name);
+			if (result == null) {
+				// last ditch find loaded check in case something is reflectively
+				// calling defineClass on our loader.
+				result = getModuleClassLoader().publicFindLoaded(name);
+			}
 			if (result != null)
 				return result;
 			throw new ClassNotFoundException(name + " cannot be found by " + this); //$NON-NLS-1$
@@ -503,7 +494,8 @@ public class BundleLoader extends ModuleLoader {
 			return result;
 		// hack to support backwards compatibility for bootdelegation
 		// or last resort; do class context trick to work around VM bugs
-		if (parent != null && !bootDelegation && ((checkParent && container.getConfiguration().compatibilityBootDelegation) || isRequestFromVM())) {
+		if (parent != null && !bootDelegation
+				&& ((container.getConfiguration().compatibilityBootDelegation) || isRequestFromVM())) {
 			// we don't need to continue if a CNFE is thrown here.
 			try {
 				return parent.loadClass(name);
@@ -592,12 +584,7 @@ public class BundleLoader extends ModuleLoader {
 	private static ClassLoader getClassLoader(final Class<?> clazz) {
 		if (System.getSecurityManager() == null)
 			return clazz.getClassLoader();
-		return AccessController.doPrivileged(new PrivilegedAction<ClassLoader>() {
-			@Override
-			public ClassLoader run() {
-				return clazz.getClassLoader();
-			}
-		});
+		return AccessController.doPrivileged((PrivilegedAction<ClassLoader>) clazz::getClassLoader);
 	}
 
 	/**
@@ -852,9 +839,9 @@ public class BundleLoader extends ModuleLoader {
 
 	public static <E> Enumeration<E> compoundEnumerations(Enumeration<E> list1, Enumeration<E> list2) {
 		if (list2 == null || !list2.hasMoreElements())
-			return list1 == null ? BundleLoader.<E> emptyEnumeration() : list1;
+			return list1 == null ? BundleLoader.emptyEnumeration() : list1;
 		if (list1 == null || !list1.hasMoreElements())
-			return list2 == null ? BundleLoader.<E> emptyEnumeration() : list2;
+			return list2 == null ? BundleLoader.emptyEnumeration() : list2;
 		List<E> compoundResults = new ArrayList<>();
 		while (list1.hasMoreElements())
 			compoundResults.add(list1.nextElement());
@@ -958,7 +945,7 @@ public class BundleLoader extends ModuleLoader {
 		for (ModuleWire bundleWire : requiredBundleWires) {
 			if (local != null || BundleNamespace.VISIBILITY_REEXPORT.equals(bundleWire.getRequirement().getDirectives().get(BundleNamespace.REQUIREMENT_VISIBILITY_DIRECTIVE))) {
 				// always add required bundles first if we locally provide the package
-				// This allows a bundle to provide a package from a required bundle without 
+				// This allows a bundle to provide a package from a required bundle without
 				// re-exporting the whole required bundle.
 				BundleLoader loader = getProviderLoader(bundleWire);
 				if (loader != null) {
@@ -1145,7 +1132,7 @@ public class BundleLoader extends ModuleLoader {
 		PackageSource result = findImportedSource(pkgName, null);
 		if (result != null)
 			return result;
-		// Note that dynamic imports are not checked to avoid aggressive wiring (bug 105779)  
+		// Note that dynamic imports are not checked to avoid aggressive wiring (bug 105779)
 		return findRequiredSource(pkgName, null);
 	}
 
@@ -1223,7 +1210,7 @@ public class BundleLoader extends ModuleLoader {
 			// so we do not have to do the search again for this package.
 			source = NullPackageSource.getNullPackageSource(pkgName);
 		} else if (result.size() == 1) {
-			// if there is just one source, remember just the single source 
+			// if there is just one source, remember just the single source
 			source = result.get(0);
 		} else {
 			// if there was more than one source, build a multisource and cache that.
@@ -1238,7 +1225,7 @@ public class BundleLoader extends ModuleLoader {
 
 	/*
 	 * Gets the package source for the pkgName.  This will include the local package source
-	 * if the bundle exports the package.  This is used to compare the PackageSource of a 
+	 * if the bundle exports the package.  This is used to compare the PackageSource of a
 	 * package from two different bundles.
 	 */
 	public final PackageSource getPackageSource(String pkgName) {
